<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

class RegisterController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(['role']);
    }
    public function index(){
        return view('auth.register');
    }

    public function allUsers(){
        if (auth()->user()->user_role === "editor") {
            return redirect()->route('dashboard');
         }
        $data = User::where("user_role", "super_admin")->orWhere("user_role", "editor")->paginate(20);
        return view('auth.all_users')->with(['data'=> $data]);
    }

    public function editUser($id){
        if (auth()->user()->user_role === "editor") {
            return redirect()->route('dashboard');
         }
        $data = User::find($id);
        // dd($data);
        return view('auth.edit_user')->with(['data'=>$data]);
    }

    public function store(Request $request){
        if (auth()->user()->user_role === "editor") {
            return redirect()->route('dashboard');
         }
        // validate
        $this->validate($request, [
            'name'=>'required|max:255',
            'username'=>'required|max:255',
            'email'=>'required|email|max:255',
            'password'=>'required|confirmed',
            'user_role'=> 'required'
        ]);
        // store
        User::create([
            'name'=>$request->name,
            'email'=>$request->email,
            'username'=>$request->username,
            'password'=> Hash::make($request->password),
            'user_role'=>$request->user_role
        ]);
        // sign in
        // redirect
        return redirect()->route('all_users');
    }
    public function update(Request $request, $id){
        if (auth()->user()->user_role === "editor") {
            return redirect()->route('dashboard');
         }
        // validate
        $this->validate($request, [
            'name'=>'required|max:255',
            'username'=>'required|max:255',
            'email'=>'required|email|max:255',
            'user_role'=> 'required'
        ]);
        // store
        if($request->password){
            
            User::where('id', $id)
                ->update([
                'name'=>$request->name,
                'email'=>$request->email,
                'username'=>$request->username,
                'password'=> Hash::make($request->password),
                'user_role'=>$request->user_role
            ]);
            // sign in
            // redirect
            if($id == auth()->user()->id){
                auth()->logout();
                return redirect()->route('login');
            }
            return redirect()->route('all_users');
        }

        User::where('id', $id)
            ->update([
            'name'=>$request->name,
            'email'=>$request->email,
            'username'=>$request->username,
            'user_role'=>$request->user_role
        ]);
        // sign in
        // redirect
        return redirect()->route('all_users');
    }

      /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        if (auth()->user()->user_role === "editor") {
            return redirect()->route('dashboard');
         }
        $employee = User::find($request->id);
        $employee->delete();
        return redirect()->route('all_users')->with('status', 'User deleted Successfully');
    }
}
