<?php

namespace App\Http\Controllers\Employees;

use App\Http\Controllers\Attendence\MonthController;
use App\Http\Controllers\Controller;
use App\Models\Employee;
use App\Models\User;
use Illuminate\Http\Request;

use Illuminate\Support\Facades\Hash;

class EmployeesController extends Controller
{
    
    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(['role']);
    }
    
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
    //   $this->createEmployeeUserAccount();
       $data = Employee::paginate(20);
       return view('employee.all_employee')->with(['data'=> $data]);
    }

    public function deletedEmployees()
    {
       $data = Employee::onlyTrashed()->paginate(20);
       return view('employee.deleted_employees')->with(['data'=> $data]);
    }

    public function createEmployeeUserAccount() {
        $allEmployees=  Employee::whereNull('deleted_at')->get();
        // dd($allEmployees);
        foreach($allEmployees as $employee){
           
        $isEmployeeAccountCreated = User::where("employee_id", $employee->id)
                                            ->where("user_role", "employee")
                                            ->orWhere("email", $employee->email)
                                            ->first();


            if(!$isEmployeeAccountCreated){
                User::create([
                    'name'=>$employee->name,
                    'email'=>$employee->email,
                    'username'=>$employee->name,
                    'password'=> "",
                    'user_role'=>"employee",
                    'employee_id'=>$employee->id
                ]);
            }
        }
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('employee.addemployee');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        
          // validate
          $this->validate($request, [
            'name'=>'required|max:255',
            'email'=>'required|email|max:255',
            'phone'=>'required|max:255',    
            'cnic'=>'required|max:255',    
            'password'=>'required|confirmed',
            'cnic_address'=>'required|max:255',    
        ]);
       
        // store
       $create =  Employee::create([
            'name'=>$request->name,
            'email'=>$request->email,
            'phone'=>$request->phone,
            'user_id'=> auth()->User()->id,
            'cnic'=>$request->cnic,
            'cnic_address'=>$request->cnic_address,
        ]);
        User::create([
            'name'=>$request->name,
            'email'=>$request->email,
            'username'=>$request->name,
            'password'=> Hash::make($request->password),
            'user_role'=>"employee",
            'employee_id'=>$create->id
        ]);
    //    dd($create->id);
        $Month = new MonthController();
        $createEmployeesMonth = $Month->createMonth($create->id);
       
        // redirect
        return redirect()->route('employee_all')->with('status', 'Employee Add Successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data = Employee::withTrashed()->find($id);
        // dd($data);
        return view('employee.show_employee')->with(['data'=>$data]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data = Employee::find($id);
        // dd($data);
        return view('employee.edit_employee')->with(['data'=>$data]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
          // validate
          $this->validate($request, [
            'name'=>'required|max:255',
            'email'=>'required|email|max:255',
            'phone'=>'required|max:255',    
            'cnic'=>'required|max:255',    
            'cnic_address'=>'required|max:255',    
        ]);
       
        // update
        $update = Employee::where('id', $id)
                ->update([
                        'name'=>$request->name,
                        'email'=>$request->email,
                        'phone'=>$request->phone,
                        'user_id'=> auth()->User()->id,
                        'cnic'=>$request->cnic, 
                        'cnic_address'=>$request->cnic_address,
                    ]);  
                    if($request->password !== ""){ 
                    User::where('employee_id', $id)
                        ->update([
                        'name'=>$request->name,
                        'email'=>$request->email,
                        'username'=>$request->name,
                        'password'=> Hash::make($request->password),
                        
                    ]);     
                } 
                else{
                    User::where('employee_id', $id)
                    ->update([
                    'name'=>$request->name,
                    'email'=>$request->email,
                    'username'=>$request->name,
                ]);  
                }


                   
        // redirect
        return redirect()->route('employee_all')->with('status', 'Employee Updated Successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $employee = Employee::find($request->item_id);
        $employeeUserAccount = User::where('employee_id', $request->item_id);
        $employeeUserAccount->delete();
        $employee->delete();
        return redirect()->route('employee_all')->with('status', 'Employee deleted Successfully');
    }
}
